@@ -1,4 +1,3 @@
-import django
 from django.conf import settings
 from django.db import models
 from django.utils.safestring import mark_safe
@@ -52,6 +51,8 @@ class Markup(object):
 
     # allows display via templates to work without safe filter
     def __unicode__(self):
+        if self.rendered is None:
+            return mark_safe('')
         return mark_safe(smart_text(self.rendered))
 
     __str__ = __unicode__
@@ -67,9 +68,6 @@ class MarkupDescriptor(object):
     def __get__(self, instance, owner):
         if instance is None:
             raise AttributeError('Can only be accessed via an instance.')
-        markup = instance.__dict__[self.field.name]
-        if markup is None:
-            return None
         return Markup(instance, self.field.name, self.rendered_field_name,
                       self.markup_type_field_name)
 
@@ -97,7 +95,13 @@ class MarkupField(models.TextField):
         self.escape_html = escape_html
 
         self.markup_choices_list = [mc[0] for mc in markup_choices]
-        self.markup_choices_dict = dict(markup_choices)
+        self.markup_choices_dict = dict((mc[0], mc[1]) for mc in markup_choices)
+        self.markup_choices_title = []
+        for mc in markup_choices:
+            if len(mc) == 3:
+                self.markup_choices_title.append(mc[2])
+            else:  # Fallback for 2-tuples (we now use 3-tuple)
+                self.markup_choices_title.append(mc[0])
 
         if (self.default_markup_type and
                 self.default_markup_type not in self.markup_choices_list):
@@ -114,14 +118,14 @@ class MarkupField(models.TextField):
         super(MarkupField, self).__init__(verbose_name, name, **kwargs)
 
     def contribute_to_class(self, cls, name):
-        if not cls._meta.abstract:
+        if self.rendered_field and not cls._meta.abstract:
             choices = zip([''] + self.markup_choices_list,
-                          ['--'] + self.markup_choices_list)
+                          ['--'] + self.markup_choices_title)
             markup_type_field = models.CharField(
                 max_length=30,
                 choices=choices, default=self.default_markup_type,
                 editable=self.markup_type_editable, blank=self.blank)
-            rendered_field = models.TextField(editable=False)
+            rendered_field = models.TextField(editable=False, null=self.null)
             markup_type_field.creation_counter = self.creation_counter + 1
             rendered_field.creation_counter = self.creation_counter + 2
             cls.add_to_class(_markup_type_field_name(name), markup_type_field)
@@ -130,17 +134,25 @@ class MarkupField(models.TextField):
 
         setattr(cls, self.name, MarkupDescriptor(self))
 
+    def deconstruct(self):
+        name, path, args, kwargs = super(MarkupField, self).deconstruct()
+        # Don't migrate rendered fields
+        kwargs['rendered_field'] = True
+        return name, path, args, kwargs
+
     def pre_save(self, model_instance, add):
         value = super(MarkupField, self).pre_save(model_instance, add)
         if value.markup_type not in self.markup_choices_list:
             raise ValueError('Invalid markup type (%s), allowed values: %s' %
-                             (value.markup_type,
-                              ', '.join(self.markup_choices_list)))
-        if self.escape_html:
-            raw = escape(value.raw)
+                             (value.markup_type, ', '.join(self.markup_choices_list)))
+        if value.raw is not None:
+            if self.escape_html:
+                raw = escape(value.raw)
+            else:
+                raw = value.raw
+            rendered = self.markup_choices_dict[value.markup_type](raw)
         else:
-            raw = value.raw
-        rendered = self.markup_choices_dict[value.markup_type](raw)
+            rendered = None
         setattr(model_instance, _rendered_field_name(self.attname), rendered)
         return value.raw
 
@@ -150,10 +162,6 @@ class MarkupField(models.TextField):
         else:
             return value
 
-    # copy get_prep_value to get_db_prep_value if pre-1.2
-    if django.VERSION < (1, 2):
-        get_db_prep_value = get_prep_value
-
     def value_to_string(self, obj):
         value = self._get_val_from_obj(obj)
         if hasattr(value, 'raw'):
