@@ -1,11 +1,14 @@
 from django.utils.html import escape, linebreaks, urlize
 from django.utils.functional import curry
+from django.utils.translation import pgettext_lazy as _
 from django.conf import settings
 
 # build DEFAULT_MARKUP_TYPES
 DEFAULT_MARKUP_TYPES = [
-    ('html', lambda markup: markup),
-    ('plain', lambda markup: linebreaks(urlize(escape(markup)))),
+    ('html', lambda markup: markup,
+     _('django-markupfield', 'HTML')),
+    ('plain', lambda markup: linebreaks(urlize(escape(markup))),
+     _('django-markupfield', 'Plain')),
 ]
 
 try:
@@ -52,12 +55,13 @@ try:
         try:
             from markdown.extensions.codehilite import makeExtension   # noqa
             md_filter = curry(markdown.markdown,
-                              extensions=['codehilite(css_class=highlight)'])
+                              extensions=[makeExtension(css_class='highlight')])
         except ImportError:
             pass
 
     # whichever markdown_filter was available
-    DEFAULT_MARKUP_TYPES.append(('markdown', md_filter))
+    DEFAULT_MARKUP_TYPES.append(('markdown', md_filter,
+                                 _('django-markupfield', 'Markdown')))
 
 except ImportError:
     pass
@@ -70,17 +74,23 @@ try:
 
     def render_rest(markup):
         overrides = getattr(settings, "RESTRUCTUREDTEXT_FILTER_SETTINGS", {})
+        overrides.update({
+            'raw_enabled': False,
+            'file_insertion_enabled': False,
+        })
         parts = publish_parts(source=markup, writer_name="html4css1",
                               settings_overrides=overrides)
         return parts["fragment"]
 
-    DEFAULT_MARKUP_TYPES.append(('restructuredtext', render_rest))
+    DEFAULT_MARKUP_TYPES.append(('restructuredtext', render_rest,
+                                 _('django-markupfield', 'Restructured Text')))
 except ImportError:
     pass
 
 try:
     import textile
     textile_filter = curry(textile.textile, encoding='utf-8', output='utf-8')
-    DEFAULT_MARKUP_TYPES.append(('textile', textile_filter))
+    DEFAULT_MARKUP_TYPES.append(('textile', textile_filter,
+                                 _('django-markupfield', 'Textile')))
 except ImportError:
     pass
