@@ -18,7 +18,9 @@ class Article(models.Model):
     normal_field = MarkupField()
     markup_choices_field = MarkupField(markup_choices=(
         ('pandamarkup', lambda x: 'panda'),
-        ('nomarkup', lambda x: x)))
+        ('nomarkup', lambda x: x),
+        ('fancy', lambda x: x[::-1], 'Some fancy Markup'),  # String reverse
+    ))
     default_field = MarkupField(default_markup_type='markdown')
     markdown_field = MarkupField(markup_type='markdown')
 
@@ -32,3 +34,11 @@ class Abstract(models.Model):
 
 class Concrete(Abstract):
     pass
+
+
+class NullTestModel(models.Model):
+    text = MarkupField(null=True, default=None, default_markup_type="markdown")
+
+
+class DefaultTestModel(models.Model):
+    text = MarkupField(null=True, default="**nice**", default_markup_type="markdown")
