@@ -1,14 +1,25 @@
-DATABASES = {
-    'default': {
-        'ENGINE': 'django.db.backends.sqlite3',
-        'NAME': 'markuptest.db'
-    }
-}
-
+import os
 import markdown
 from django.utils.html import escape, linebreaks, urlize
 from docutils.core import publish_parts
 
+if os.environ.get('DB') == 'postgres':
+    DATABASES = {
+        'default': {
+            'ENGINE': 'django.db.backends.postgresql_psycopg2',
+            'NAME': 'test',
+            'USER': 'postgres',
+            'PASSWORD': '',
+        }
+    }
+else:
+    DATABASES = {
+        'default': {
+            'ENGINE': 'django.db.backends.sqlite3',
+            'NAME': 'markuptest.db'
+        }
+    }
+
 
 def render_rest(markup):
     parts = publish_parts(source=markup, writer_name="html4css1")
@@ -25,3 +36,5 @@ INSTALLED_APPS = (
 )
 
 SECRET_KEY = 'sekrit'
+
+MIDDLEWARE_CLASSES = ()
