@@ -8,7 +8,7 @@ from django.utils.encoding import smart_text
 from markupfield.markup import DEFAULT_MARKUP_TYPES
 from markupfield.fields import MarkupField, Markup
 from markupfield.widgets import MarkupTextarea, AdminMarkupTextareaWidget
-from markupfield.tests.models import Post, Article, Concrete
+from markupfield.tests.models import Post, Article, Concrete, NullTestModel, DefaultTestModel
 
 from django.forms.models import modelform_factory
 ArticleForm = modelform_factory(Article, fields=['normal_field', 'normal_field_markup_type',
@@ -59,7 +59,8 @@ class MarkupFieldTestCase(TestCase):
         self.assertEqual(smart_text(p1.body),
                          '<p><strong>markdown</strong></p>')
 
-    ## Assignment ##
+    # Assignment #########
+
     def test_body_assignment(self):
         self.rp.body = '**ReST**'
         self.rp.save()
@@ -82,7 +83,7 @@ class MarkupFieldTestCase(TestCase):
         self.assertEqual(self.rp.body.markup_type, 'markdown')
         self.assertEqual(smart_text(self.rp.body), '<p><em>ReST</em></p>')
 
-    ## Serialization ##
+    # Serialization ###########
 
     def test_serialize_to_json(self):
         stream = serializers.serialize('json', Post.objects.all())
@@ -134,7 +135,9 @@ class MarkupFieldTestCase(TestCase):
                         "comment_markup_type": "plain",
                         "body_markup_type": "plain"}},
         ]
-        self.assertEqual(expected, actual)
+        self.assertEqual(len(expected), len(actual))
+        for n, item in enumerate(expected):
+            assert item['fields'] == actual[n]['fields']
 
     def test_deserialize_json(self):
         stream = serializers.serialize('json', Post.objects.all())
@@ -154,7 +157,7 @@ class MarkupFieldTestCase(TestCase):
         self.assertNotEqual(field.value_to_string(obj), u'')    # expected
         self.assertEqual(field.value_to_string(None), u'')      # edge case
 
-    ## Other ##
+    # Other #################
 
     def test_escape_html(self):
         # the rendered string has been escaped
@@ -185,7 +188,7 @@ class MarkupFieldTestCase(TestCase):
             self.assertTrue(hasattr(rendered, '__str__'))
 
     def test_plain_markup_urlize(self):
-        for key, func in DEFAULT_MARKUP_TYPES:
+        for key, func, _ in DEFAULT_MARKUP_TYPES:
             if key != 'plain':
                 continue
             txt1 = 'http://example.com some text'
@@ -250,6 +253,12 @@ class MarkupWidgetTests(TestCase):
                         ArticleForm().fields.keys())
 
     def test_markup_type_choices(self):
+        # This function primarily tests the choices available to the widget.
+        # By introducing titled markups (as third element in the markup_choices
+        # tuples), this function also shows the backwards compatibility to the
+        # old 2-tuple style and, by checking for the title of the 'fancy'
+        # markup in the second test, also for the correkt title to the widget
+        # choices.
         self.assertEqual(
             ArticleForm().fields['normal_field_markup_type'].choices,
             [('', '--'), ('markdown', 'markdown'), ('ReST', 'ReST'),
@@ -257,7 +266,7 @@ class MarkupWidgetTests(TestCase):
         self.assertEqual(
             ArticleForm().fields['markup_choices_field_markup_type'].choices,
             [('', '--'), ('pandamarkup', 'pandamarkup'),
-             ('nomarkup', 'nomarkup')])
+             ('nomarkup', 'nomarkup'), ('fancy', 'Some fancy Markup')])
 
     def test_default_markup_type(self):
         self.assertTrue(
@@ -272,3 +281,46 @@ class MarkupWidgetTests(TestCase):
         ma = admin.ModelAdmin(Post, admin.site)
         self.assertTrue(isinstance(ma.formfield_for_dbfield(
             Post._meta.get_field('body')).widget, AdminMarkupTextareaWidget))
+
+
+class MarkupFieldLocalFileTestCase(TestCase):
+    def test_no_raw(self):
+        for markup_opt in DEFAULT_MARKUP_TYPES:
+            if markup_opt[0] == 'restructuredtext':
+                render_rest = markup_opt[1]
+        body = render_rest('.. raw:: html\n    :file: AUTHORS.txt')
+
+        self.assertNotIn('James Turk', body)
+
+
+class MarkupWidgetRenderTestCase(TestCase):
+    def test_model_admin_render(self):
+        from django.utils.translation import ugettext_lazy as _
+        w = AdminMarkupTextareaWidget()
+        assert w.render(_('body'), _('Body'))
+
+
+class NullTestCase(TestCase):
+    def test_default_null_save(self):
+        m = NullTestModel()
+        m.save()
+        self.assertEqual(smart_text(m.text), '')
+        self.assertIsNone(m.text.raw)
+        self.assertIsNone(m.text.rendered)
+
+
+class DefaultTestCase(TestCase):
+    def test_default_text_save(self):
+        m = DefaultTestModel()
+        m.save()
+        self.assertEqual(smart_text(m.text), "<p><strong>nice</strong></p>")
+
+    def test_assign_none(self):
+        m = DefaultTestModel()
+        m.save()
+        self.assertEqual(smart_text(m.text), "<p><strong>nice</strong></p>")
+        m.text.raw = None
+        m.save()
+        self.assertEqual(smart_text(m.text), '')
+        self.assertIsNone(m.text.raw)
+        self.assertIsNone(m.text.rendered)
